<html lang="en">
<head>
  <meta charset="utf-8">
  <title>webpty</title>
  <link rel="preconnect" href="https://fonts.gstatic.com">
  <link href="https://fonts.googleapis.com/css2?family=Source+Code+Pro&display=swap" rel="stylesheet">
  
  <link rel="stylesheet" href=".{{ static_url("xterm.min.css") }}" />
  <link rel="stylesheet" href=".{{ static_url("xterm-addons/fullscreen.min.css") }}" />
  <link rel="stylesheet" href=".{{ static_url("webpty.css") }}" />
</head>
<body>
    <div id="terminal"></div>

    <!-- Javascripts -->
    <script src=".{{ static_url("xterm.min.js") }}"></script>
    <script src=".{{ static_url("xterm-addons/fullscreen.min.js") }}"></script>
    <script src=".{{ static_url("xterm-addons/fit.min.js") }}"></script>
    <script src=".{{ static_url("webpty.js") }}"></script>
</body>
</html>
