* {
    margin: 0;
    font-family: 'Source Code Pro', monospace !important;
}

html{
    min-height:100%;/* make sure it is at least as tall as the viewport */
    position:relative;
}

body{
    height:100%; /* force the BODY element to match the height of the HTML element */
}

#terminal {
    position:absolute;
    top:0;
    bottom:0;
    left:0;
    right:0;
    overflow:hidden;
}
